![logo](./doc/source/logo.png)

[![Build Status](https://travis-ci.com/shuaigroup/Renormalizer.svg?branch=master)](https://app.travis-ci.com/github/shuaigroup/Renormalizer)

Renormalizer is a python package based on tensor network states for electron-phonon quantum dynamics.

## Installation
Installation guide can be found in the [project wiki](https://github.com/shuaigroup/Renormalizer/wiki/Installation-guide).

## Documentation
Primitive documentation could be found [here](https://shuaigroup.github.io/Renormalizer/).

## Notice
* Renormalizer is still under heavy development. Drastic API changes come without any prior deprecation.